"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Oracle = void 0;
const n8n_workflow_1 = require("n8n-workflow");
const OracleApiTest_1 = require("./OracleApiTest");
const oracledb_1 = __importDefault(require("oracledb"));
class Oracle {
    constructor() {
        this.description = {
            displayName: 'Oracle',
            name: 'oracle',
            icon: 'file:oracle.svg',
            group: ['input'],
            version: 1,
            subtitle: '={{$parameter["operation"]}}',
            description: `Consume Oracle API`,
            defaults: {
                name: 'Oracle',
                color: '#EFEFEF',
            },
            inputs: ['main'],
            outputs: ['main'],
            credentials: [
                {
                    name: 'oracleApi',
                    required: true,
                },
            ],
            properties: [
                {
                    displayName: 'Operation',
                    name: 'operation',
                    required: true,
                    type: 'options',
                    options: [
                        {
                            name: 'Execute Query',
                            value: 'executeQuery',
                        },
                    ],
                    default: 'executeQuery',
                    description: '',
                },
                {
                    displayName: 'Query',
                    name: 'query',
                    required: true,
                    type: 'string',
                    typeOptions: {
                        editor: 'sqlEditor',
                        rows: 5,
                        sqlDialect: 'PLSQL',
                    },
                    displayOptions: {
                        show: {
                            operation: ['executeQuery'],
                        },
                    },
                    default: '',
                    placeholder: 'e.g. SELECT id, name FROM product WHERE quantity > :quantity AND price <= :price',
                    description: 'The SQL query to execute. You can use bind variables set in the options below.',
                },
                {
                    displayName: 'Options',
                    name: 'options',
                    type: 'collection',
                    placeholder: 'Add Option',
                    default: {},
                    options: [
                        {
                            displayName: 'Bind Params',
                            name: 'bindParams',
                            type: 'json',
                            default: '',
                            description: 'An object (not string) with the properties you want to use as bind variables. <a href="https://node-oracledb.readthedocs.io/en/latest/user_guide/bind.html" target="_blank">More info</a>.',
                        },
                        {
                            displayName: 'Thick Mode',
                            name: 'thickMode',
                            type: 'boolean',
                            default: false,
                            description: 'Use thick connection mode. <a href="https://node-oracledb.readthedocs.io/en/latest/user_guide/bind.html" target="_blank">More info</a>.',
                        },
                    ],
                },
                {
                    displayName: 'When using thick mode, an Oracle Instant Client should be available. ' +
                        'See <a href="// https://node-oracledb.readthedocs.io/en/latest/user_guide/initialization.html#enabling-node-oracledb-thick-mode-on-linux-and-related-platforms" target="_blank">the docs</a>.',
                    name: 'jsonNotice',
                    type: 'notice',
                    displayOptions: {
                        show: {
                            '/options.thickMode': [true],
                        },
                    },
                    default: '',
                },
            ],
        };
        this.methods = {
            credentialTest: {
                oracleApiTest: OracleApiTest_1.oracleApiTest,
            },
        };
    }
    async execute() {
        const items = this.getInputData();
        let responseData;
        const returnData = [];
        const operation = this.getNodeParameter('operation', 0);
        const credentials = await this.getCredentials('oracleApi');
        for (let i = 0; i < items.length; i++) {
            try {
                const options = this.getNodeParameter('options', i);
                if (options.thickMode) {
                    oracledb_1.default.initOracleClient();
                }
                const connectionConfig = {
                    user: credentials.user,
                    password: credentials.password,
                    connectString: `(DESCRIPTION=(ADDRESS_LIST=(ADDRESS=(PROTOCOL=TCP)(HOST=${credentials.host})(PORT=${credentials.port})))(CONNECT_DATA=(SID=${credentials.sid})))`,
                    externalAuth: false,
                };
                const connection = await oracledb_1.default.getConnection(connectionConfig);
                const bindParams = (options.bindParams || {});
                let sql;
                switch (operation) {
                    case 'executeQuery': {
                        sql = this.getNodeParameter('query', i);
                        break;
                    }
                    default:
                        throw new n8n_workflow_1.NodeOperationError(this.getNode(), `The operation "${operation}" is not supported"!`);
                }
                if (bindParams) {
                    responseData = await connection.execute(sql, bindParams);
                }
                else {
                    responseData = await connection.execute(sql);
                }
                await connection.close();
                if (!responseData || Object.keys(responseData).length == 0) {
                    responseData = {
                        success: true,
                    };
                }
                if (Array.isArray(responseData)) {
                    returnData.push.apply(returnData, responseData);
                }
                else if (responseData !== undefined) {
                    returnData.push(responseData);
                }
            }
            catch (error) {
                if (this.continueOnFail()) {
                    returnData.push({ error: error.message });
                    continue;
                }
                throw error;
            }
        }
        return [this.helpers.returnJsonArray(returnData)];
    }
}
exports.Oracle = Oracle;
//# sourceMappingURL=Oracle.node.js.map